<?php
/**
 * Custom template tags for this theme
 *
 * @subpackage Construction Firm
 * @since 1.0
 */

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */

if ( ! function_exists( 'construction_firm_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function construction_firm_entry_footer() {
	$construction_firm_separate_meta = __( ', ', 'construction-firm' );
	$construction_firm_categories_list = get_the_category_list( $construction_firm_separate_meta );
	$construction_firm_tags_list = get_the_tag_list( '', $construction_firm_separate_meta );
	if ( ( ( construction_firm_categorized_blog() && $construction_firm_categories_list ) || $construction_firm_tags_list ) || get_edit_post_link() ) {

		echo '<footer class="entry-footer">';

			construction_firm_edit_link();

		echo '</footer> <!-- .entry-footer -->';
	}
}
endif;

if ( ! function_exists( 'construction_firm_edit_link' ) ) :
function construction_firm_edit_link() {
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			__( 'Edit<span class="screen-reader-text"> "%s"</span>', 'construction-firm' ),
			get_the_title()
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

function construction_firm_categorized_blog() {
	$construction_firm_category_count = get_transient( 'construction_firm_categories' );

	if ( false === $construction_firm_category_count ) {
		// Create an array of all the categories that are attached to posts.
		$construction_firm_categories = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$construction_firm_category_count = count( $construction_firm_categories );

		set_transient( 'construction_firm_categories', $construction_firm_category_count );
	}

	// Allow viewing case of 0 or 1 categories in post preview.
	if ( is_preview() ) {
		return true;
	}

	return $construction_firm_category_count > 1;
}

if ( ! function_exists( 'construction_firm_the_custom_logo' ) ) :

function construction_firm_the_custom_logo() {
	the_custom_logo();
}
endif;

function construction_firm_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'construction_firm_categories' );
}
add_action( 'edit_category', 'construction_firm_category_transient_flusher' );
add_action( 'save_post',     'construction_firm_category_transient_flusher' );
